@@ -2,9 +2,13 @@
 #include <stdarg.h>
 #include <errno.h>
 #include <string.h>
-#include <endian.h>
 
-//#include <usb.h>
+/* Try to find endianess , standard C header? */
+#ifndef USE_OSX
+#include <endian.h>			
+#else
+#include <machine/endian.h>
+#endif
 
 #include "font.h"
 #include  "f60lib.h"
@@ -21,6 +25,10 @@ int ep_addr_read = F60_EPA_2;
 
 int selected_memory = FLASH_MEMORY;
 
+int mpman_type = MPMAN_F60;
+int filename_offset = 21;
+
+
 struct usb_device *f60_dev = NULL;
 
 const char F60_CmdTerminator = 0x04;
@@ -60,13 +68,13 @@ char* f60_strip_path(char* filename) {
      return c;
 }
 
-#ifndef __BYTE_ORDER
-#error  "__BYTE_ORDER not defined"
+#ifndef BYTE_ORDER
+#error  "BYTE_ORDER not defined"
 #endif
 
 // byteswap should only be done on little endian machines. should rename functions
 void f60_big2little_endian(int* from,int* to) {
- #if __BYTE_ORDER == LITTLE_ENDIAN
+ #if BYTE_ORDER == LITTLE_ENDIAN
      char* f;
      char* t;
 
@@ -84,7 +92,7 @@ void f60_big2little_endian(int* from,int* to) {
 }
 
 void f60_little2big_endian(int* from,int* to) {
- #if __BYTE_ORDER == LITTLE_ENDIAN
+ #if BYTE_ORDER == LITTLE_ENDIAN
      char* f;
      char* t;
 
@@ -188,6 +196,14 @@ int f60_check_for_device() {
 }
 */
 
+// patch by Lewis Jardine, to fix a difference in the F50
+void mpman_specific_setup() {
+	if (mpman_type == MPMAN_F50)
+	{filename_offset = 18;}
+	else
+	{filename_offset = 21;}
+}
+
 struct usb_dev_handle* f60_init() {
      struct usb_dev_handle* ret;
  
@@ -199,6 +215,7 @@ struct usb_dev_handle* f60_init() {
      // Check for F50 product ID
      if (!f60_dev) {
 	  f60_dev = f60_get_device_by_id(F50_VENDOR_ID,F50_PRODUCT_ID);
+	  if (f60_dev) mpman_type == MPMAN_F50;
 	  if (debug && f60_dev) printf("Found MP-Man F50\n");
      }
 	
@@ -221,6 +238,8 @@ struct usb_dev_handle* f60_init() {
      usb_claim_interface(ret,f60_dev->config->interface->altsetting->bInterfaceNumber);
      usb_set_altinterface(ret,f60_dev->config->interface->altsetting->bAlternateSetting);
 
+
+	mpman_specific_setup();
      return ret;
 }
 
@@ -250,6 +269,7 @@ struct usb_dev_handle* f60_init_with_id(unsigned short vendor,
      usb_claim_interface(ret,f60_dev->config->interface->altsetting->bInterfaceNumber);
      usb_set_altinterface(ret,f60_dev->config->interface->altsetting->bAlternateSetting);
 
+	mpman_specific_setup();
      return ret;
 }
 
@@ -554,7 +574,7 @@ char* f60_get_file(usb_dev_handle *dev,unsigned char index,char* path) {
      ret = f60_read(dev,filemap,filesize,20000);
      if (!ret) goto error;
 
-     filename = f60_strip_path(&response[21]);
+     filename = f60_strip_path(&response[filename_offset]);
 
      if (path[strlen(path) - 1] == '/')
 	  snprintf(fullpath,256,"%s%s",path,filename);
@@ -584,6 +604,7 @@ error:
      return NULL;
 }
 
+
 int f60_delete_file(usb_dev_handle *dev,unsigned char index) {
      int ret;
 
@@ -614,11 +635,40 @@ int f60_format_media(usb_dev_handle *dev, char x1) {
 }
 
 
+/* This was originally based on code from the 'globecom jukebox', however the only thing it has 
+   in common is the names of the variables. The first half was re-written by me to fit the architecture
+   of f60lib, and the second half was re-written by me to actually detect id3v2s, and calculate the size correctly.
+
+   There is no globecom jukebox code remaining in this function, however the overall structure is
+   similar. I believe that there are very few sensible ways to find the size of an id3v2, and reading the header
+   into an array which is then tested is too obvious an idea to copyright.
+
+   patch by Lewis Jardine
+*/
+
+int getV2Size(char* id3head)
+{
+  int toreturn;
+
+  if ((id3head[0] != 0x49) || (id3head[1] != 0x44) || (id3head[2] != 0x33)) {
+  printf("no V2 header\n"); 
+    return 0;
+  }
+    
+  toreturn = 10+id3head[9]+id3head[8]*128+id3head[7]*128*128+id3head[6]*128*128*128;
+  return toreturn;
+}
+
+
+
 int f60_encode_file(char* source,char* dest) {
      FILE* src = NULL;
      FILE* dst = NULL;
      int i;
      int ii;
+     int id3v2size;
+	char id3head[10];
+
      int byteswritten;
      unsigned char buffer[512];
      char inchar;
@@ -635,6 +685,21 @@ int f60_encode_file(char* source,char* dest) {
 	  f60_set_error(F60_ERROR_OTHER,"cant open encode output file");
 	  goto error;
      }
+
+
+/* Skip ID3v2, as it confuses the mpman */
+		id3v2size = 0; i = 0;
+		/* Copy header into a buffer for jukebox code to parse */
+		while (!feof(src)) 
+			{id3head[i] = fgetc(src); if (i == 9) break; i++;}
+		/* getv2size will return 0 if it does not understand the header, which will 
+		     reset the file pointer to the start, just as if we'd never tried to read the header.*/
+		id3v2size = getV2Size(id3head);
+		if (debug) printf("ID3v2 tag is %d bytes\n", id3v2size);
+		fseek (src, id3v2size, SEEK_SET);
+/* Skip ID3v2, as it confuses the mpman */
+
+
      i=0; ii=0;
      while (!feof(src)) {
 	  inchar = fgetc(src);
