@@ -1,3 +1,26 @@
+/*
+ * mainwindow.c
+ * This file is part of mplinuxman
+ *
+ * Copyright (C) 2002-2006 - Tim O'Brien
+ * Copyright (C) 2006 - Boško Andjelković
+ *
+ * mplinuxman is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * mplinuxman is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with mplinuxman; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Boston, MA  02110-1301  USA
+ */
+
 /* Main Window code 
 
    A good example of how not to do things....
@@ -158,92 +181,6 @@ void MplinuxError() {
      gtk_dialog_set_has_separator (GTK_DIALOG(dialog),FALSE);
      gtk_widget_show_all(dialog);
 }
-    
-void dirsel_cb(gchar* dirname,gint button) {
-     GtkWidget* tv;
-     GtkTreeModel* model;
-     GtkTreeIter iter;
-     GList* entries= NULL;
-     GList* p;
-     gint n;
-
-     if (!button)
-	  return;
-
-     cfg_Write("paths","add directory",dirname);
-     entries = CreateWaitDialog((GThreadFunc)pl_AddDirectory,dirname,
-				pl_AddDirectoryCancel,NULL,_("Reading Directory"));
-//     entries = pl_AddDirectory(dirname);
-
-     if (g_list_length(entries) == 0) {
-	  cfg_Write("paths","add directory","/");
-	  return;
-     }
-
-     tv = MW_GET("left_treeview");
-     gtk_widget_grab_focus (tv);
-
-     model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
-
-     n = gtk_tree_model_iter_n_children(model,NULL);
-     if (n)
-	  gtk_tree_model_iter_nth_child(model,&iter,NULL,n -1);
-
-
-     for(p = entries;p;p = g_list_next(p)) {
-	  gtk_list_store_append(GTK_LIST_STORE(model),&iter);     
-	  gtk_list_store_set(GTK_LIST_STORE(model),&iter,0,p->data,-1);
-     }
-
-     g_list_free(entries);
-}
-
-void filesel_AddFile (GtkFileSelection *selector, gpointer file_selector) {
-     gchar* selected_filename;
-     PlayListEntry* p;
-     GtkWidget* tv;
-     GtkTreeModel* model;
-     GtkTreeIter iter;
-     gint n;
-
-     selected_filename = (gchar*) gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_selector));
-     if (!pl_GetMp3Info(selected_filename) )
-     	return;
-     p = pl_AddFile(selected_filename);
-
-     if (!p)
-	  return;
-
-     cfg_Write("paths","add file",selected_filename);
-     tv = MW_GET("left_treeview");
-	 gtk_widget_grab_focus (tv);
-     model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
-
-     n = gtk_tree_model_iter_n_children(model,NULL);
-     if (n)
-	  gtk_tree_model_iter_nth_child(model,&iter,NULL,n -1);
-     gtk_list_store_append(GTK_LIST_STORE(model),&iter);     
-     gtk_list_store_set(GTK_LIST_STORE(model),&iter,0,p,-1);
-     
-}
-
-
-void filesel_SendNonMp3 (GtkFileSelection *selector, gpointer file_selector) {
-	gchar* selected_filename;
-	gint ret;
-	
-	selected_filename = (gchar*) gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_selector));
-
-    ret = (gint) CreateWaitDialog((GThreadFunc)mpl_SendFileNonMp3,selected_filename,NULL,
-													mpl_GetReadWriteProgress,_("sending file"));
-    if (ret == MPL_ERROR) {
-	 MplinuxError();
-	 return;
-    }
-
-    right_treeview_Refresh(NULL,NULL);
-
-}
 	
 void left_treeview_cell_RenderName (GtkTreeViewColumn *tree_column,
 				    GtkCellRenderer   *cell,
@@ -522,77 +459,151 @@ void right_list_button_Clicked(GtkButton *button,gpointer user_data) {
 gboolean popup_AddDirectory(GtkWidget *widget,
 		      GdkEventButton *event,
 		      gpointer user_data) {
+	gchar* c;
+	c = cfg_Read("paths","add directory","/");
+	if (GTK_WIDGET_TYPE(user_data) == gtk_menu_get_type())
+		gtk_menu_popdown(GTK_MENU(user_data));
+	
+	gchar *dirname;
+	GtkWidget *dialog;
+	dialog = gtk_file_chooser_dialog_new (_("Add directory..."),MainWindow,GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,NULL);
+	gtk_file_chooser_set_filename   (GTK_FILE_CHOOSER (dialog),c);
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+	if(result == GTK_RESPONSE_ACCEPT)
+	{
+		gchar *selected_filename;
+		selected_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		dirname = dirsel_convert_if_needed (selected_filename);
+		gtk_widget_destroy (dialog);
+		GtkWidget* tv;
+		GtkTreeModel* model;
+		GtkTreeIter iter;
+		GList* entries= NULL;
+		GList* p;
+		gint n;
+		
+		cfg_Write("paths","add directory",dirname);
+		entries = CreateWaitDialog((GThreadFunc)pl_AddDirectory,dirname,pl_AddDirectoryCancel,NULL,_("Reading Directory"));
+		//     entries = pl_AddDirectory(dirname);
 
-     GtkWindow* w;
-     gchar* c;
-     
-     c = cfg_Read("paths","add directory","/");
-     if (GTK_WIDGET_TYPE(user_data) == gtk_menu_get_type())
-	  gtk_menu_popdown(GTK_MENU(user_data));
-     w = dirsel_create_dialog(dirsel_cb,c);
-     gtk_window_set_modal(w,TRUE);  
-     g_object_set(w,"window-position",GTK_WIN_POS_CENTER,NULL);
-     gtk_window_set_transient_for(w,MainWindow);
-     gtk_widget_show_all(GTK_WIDGET(w));
+		if (g_list_length(entries) == 0)
+		{
+			cfg_Write("paths","add directory","/");
+	  		return;
+		}
 
-     return FALSE;
+		tv = MW_GET("left_treeview");
+		gtk_widget_grab_focus (tv);
+		
+		model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
+		
+		n = gtk_tree_model_iter_n_children(model,NULL);
+		if (n)
+			gtk_tree_model_iter_nth_child(model,&iter,NULL,n -1);
+			
+		for(p = entries;p;p = g_list_next(p))
+		{
+			gtk_list_store_append(GTK_LIST_STORE(model),&iter);     
+			gtk_list_store_set(GTK_LIST_STORE(model),&iter,0,p->data,-1);
+		}
+		
+     		g_list_free(entries);
+		g_free (selected_filename);
+	}
+	else
+	{
+		gtk_widget_destroy (dialog);
+	}
+
+	return FALSE;
 }
 
 gboolean popup_AddFile(GtkWidget *widget,
 		      GdkEventButton *event,
 		      gpointer user_data) {
-     GtkWidget* file_selector;
-     gchar* c;
+     	gchar* c;
 
-     gtk_menu_popdown(GTK_MENU(user_data));
-     file_selector = gtk_file_selection_new (_("Select File"));
-     c =  cfg_Read("paths","add file","/");
-     gtk_file_selection_set_filename (GTK_FILE_SELECTION(file_selector),c);
-     gtk_window_set_modal(GTK_WINDOW(file_selector),TRUE);  
-     gtk_window_set_transient_for(GTK_WINDOW(file_selector),MainWindow);
-     g_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->ok_button),
-		       "clicked",
-		       G_CALLBACK (filesel_AddFile),
-		       file_selector);
-     g_signal_connect_swapped (GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->ok_button),
-			       "clicked",
-			       G_CALLBACK (gtk_widget_destroy), 
-			       (gpointer) file_selector); 
-     g_signal_connect_swapped (GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->cancel_button),
-			       "clicked",
-			       G_CALLBACK (gtk_widget_destroy),
-			       (gpointer) file_selector); 
-     gtk_widget_show (file_selector);    
+    	gtk_menu_popdown(GTK_MENU(user_data));
 
-     return FALSE;
+     	c =  cfg_Read("paths","add file","/");
+
+	GtkWidget *dialog;
+	dialog = gtk_file_chooser_dialog_new (_("Add file..."),MainWindow,GTK_FILE_CHOOSER_ACTION_OPEN,GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,NULL);
+	GtkFileFilter *filter;				   
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("Music Files"));
+	gtk_file_filter_add_pattern (filter, "*.mp3");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
+	gtk_file_chooser_set_filename   (GTK_FILE_CHOOSER (dialog),c);
+	gtk_window_set_modal(GTK_WINDOW(dialog),TRUE);  
+	
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+	if(result == GTK_RESPONSE_ACCEPT)
+	{
+		char *selected_filename;
+		selected_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		PlayListEntry* p;
+		GtkWidget* tv;
+		GtkTreeModel* model;
+     		GtkTreeIter iter;
+     		gint n;
+
+     		if (!pl_GetMp3Info(selected_filename) )
+     		{
+     			gtk_widget_destroy (dialog);
+     			return;
+     		}
+     		p = pl_AddFile(selected_filename);
+
+     		if (!p)
+		{
+    			gtk_widget_destroy (dialog);
+	  		return;
+	  	}
+
+		cfg_Write("paths","add file",selected_filename);
+		tv = MW_GET("left_treeview");
+		gtk_widget_grab_focus (tv);
+		model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
+
+		n = gtk_tree_model_iter_n_children(model,NULL);
+		if (n)
+			gtk_tree_model_iter_nth_child(model,&iter,NULL,n -1);
+		gtk_list_store_append(GTK_LIST_STORE(model),&iter);     
+		gtk_list_store_set(GTK_LIST_STORE(model),&iter,0,p,-1);
+
+		g_free (selected_filename);
+	}
+
+	gtk_widget_destroy (dialog);
+	return FALSE;
 }
 
 void menuitem_SendNonMp3 (gpointer callback_data,
 		     guint  callback_action,
 		     GtkWidget *widget) {
-				 
-     GtkWidget* file_selector;
-     gchar* c;
-
-     file_selector = gtk_file_selection_new (_("Select File"));
-     //c =  cfg_Read("paths","add file","/");
-     gtk_file_selection_set_filename (GTK_FILE_SELECTION(file_selector),"/");
-     gtk_window_set_modal(GTK_WINDOW(file_selector),TRUE);  
-     gtk_window_set_transient_for(GTK_WINDOW(file_selector),MainWindow);
-     g_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->ok_button),
-		       "clicked",
-		       G_CALLBACK (filesel_SendNonMp3),
-		       file_selector);
-     g_signal_connect_swapped (GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->ok_button),
-			       "clicked",
-			       G_CALLBACK (gtk_widget_destroy), 
-			       (gpointer) file_selector); 
-     g_signal_connect_swapped (GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->cancel_button),
-			       "clicked",
-			       G_CALLBACK (gtk_widget_destroy),
-			       (gpointer) file_selector); 
-     gtk_widget_show (file_selector);    
-
+	GtkWidget *dialog;
+	dialog = gtk_file_chooser_dialog_new (_("Send non-Mp3 file..."),MainWindow,GTK_FILE_CHOOSER_ACTION_OPEN,GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,NULL);
+	gtk_window_set_modal(GTK_WINDOW(dialog),TRUE);  
+	
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+	if(result == GTK_RESPONSE_ACCEPT)
+	{
+		gchar *selected_filename;
+		selected_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		gtk_widget_destroy (dialog);
+		gint ret;
+		ret = (gint) CreateWaitDialog((GThreadFunc)mpl_SendFileNonMp3,selected_filename,NULL,mpl_GetReadWriteProgress,_("sending file"));
+    		if (ret == MPL_ERROR)
+    		{
+			MplinuxError();
+			return;
+		}
+    		right_treeview_Refresh(NULL,NULL);
+		g_free (selected_filename);
+	}
+	else
+		gtk_widget_destroy (dialog);
 }
 
 
@@ -648,6 +659,24 @@ gboolean popup_Context(GtkWidget *widget,
 		   cmd = g_string_append(cmd,"\"");
 		   cmd = g_string_append(cmd,(gchar*)ptr->data);
 		   cmd = g_string_append(cmd,"\" ");
+		GString *fn = g_string_new("");
+		GtkRecentManager *manager;
+		GtkRecentData *recent_data;
+		manager = gtk_recent_manager_new ();
+		recent_data = g_new0 (GtkRecentData, 1);
+		recent_data->mime_type = "audio/mpeg";
+		recent_data->app_name = "mplinuxman";
+		recent_data->app_exec = g_strjoin (" ", g_strsplit_set (c, " ", -1)[0], "%u", NULL);
+		//recent_data->display_name = g_path_get_basename((gchar*)ptr->data);
+		fn = g_string_append (fn,"file://");
+		fn = g_string_append (fn,g_strescape ((gchar*)ptr->data,NULL));
+		if (!gtk_recent_manager_add_full (manager,fn->str, recent_data))
+		{
+			/* warn about the error */
+		}
+		g_free (recent_data->app_exec);
+		g_free (recent_data);
+		g_object_unref (manager);
 	      }
 	      cmd = g_string_append(cmd,strstr(c,"%f") + 2);
 	 }
@@ -873,40 +902,39 @@ void right_treeview_MpGetSelection (GtkTreeModel *model,
      }
 }
 
-
-void dirsel_cb2(gchar* dirname,gint button) {
-     GtkWidget* tv;
-     GtkTreeModel* model;
-     GtkTreeSelection* selection;
-
-     if (!button)
-	  return;
-
-     cfg_Write("paths","save directory",dirname);
-
-     tv = MW_GET("right_treeview");
-
-    model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
-    selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tv));
-    gtk_tree_selection_selected_foreach (selection,
-			      (GtkTreeSelectionForeachFunc)right_treeview_MpGetSelection ,
-				      dirname);
-}
-
 void toolbar_GetFiles(gpointer callback_data,
 		     guint  callback_action,
 		     GtkWidget *widget) {
-     
-     GtkWindow* w;
-     gchar*c;
+	gchar*c;
+	c = cfg_Read("paths","save directory","/");
 
-     c = cfg_Read("paths","save directory","/");
-     w = dirsel_create_dialog(dirsel_cb2,c);
-     gtk_window_set_modal(w,TRUE);  
-     gtk_window_resize(w,400,400);
-     gtk_window_set_transient_for(w,MainWindow);
-     gtk_widget_show_all(GTK_WIDGET(w));
-     
+	GtkWidget *dialog;
+	dialog = gtk_file_chooser_dialog_new (_("Select save directory..."),MainWindow,GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,NULL);
+	gtk_window_set_transient_for(GTK_WINDOW(dialog),MainWindow);
+	gtk_file_chooser_set_filename   (GTK_FILE_CHOOSER (dialog),c);
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+	if(result == GTK_RESPONSE_ACCEPT)
+	{
+		gchar *selected_filename;
+		gchar *dirname;
+		selected_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		dirname = dirsel_convert_if_needed (selected_filename);
+		
+		GtkWidget* tv;
+		GtkTreeModel* model;
+		GtkTreeSelection* selection;
+		cfg_Write("paths","save directory",dirname);
+		tv = MW_GET("right_treeview");
+		model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
+		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tv));
+		gtk_tree_selection_selected_foreach (selection,(GtkTreeSelectionForeachFunc)right_treeview_MpGetSelection ,dirname);
+		gtk_widget_destroy (dialog);
+		g_free (selected_filename);
+	}
+	else
+	{
+		gtk_widget_destroy (dialog);
+	}          
 }
 
 void toolbar_Refresh(gpointer callback_data,
@@ -1037,97 +1065,110 @@ void menuitem_SelectAll(gpointer callback_data,
 	  
 }
 
-void menuitem_LoadPlaylist(gpointer callback_data,
-		     guint  callback_action,
-		     GtkWidget *widget) {
+void menuitem_LoadPlaylist(gpointer callback_data,guint  callback_action,GtkWidget *widget)
+{
+	GtkWidget* tv;
+	GtkTreeModel* model;
+	GtkTreeSelection* selection;
+	GtkTreeIter iter;
+	GList* entries = NULL, *p =NULL;
+	gchar* c;
+	GtkWidget *dialog;
+	GtkFileFilter *filter;		
+			   
+	tv = MW_GET("left_treeview");
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tv));
+	if ((gint) callback_action != 3)
+	{
+		dialog = gtk_file_chooser_dialog_new (_("Select playlist..."),MainWindow,GTK_FILE_CHOOSER_ACTION_OPEN,GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,NULL);
+		filter = gtk_file_filter_new ();
+		gtk_file_filter_set_name (filter, _("Playlists"));
+		gtk_file_filter_add_pattern (filter, "*.m3u");
+		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
+		c = cfg_Read("paths","playlist","/");
+		gtk_file_chooser_set_filename   (GTK_FILE_CHOOSER (dialog),c);
+		gtk_window_set_modal(GTK_WINDOW(dialog),TRUE);  
+		gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+		if (result == GTK_RESPONSE_CANCEL)
+		{
+			gtk_widget_destroy (dialog);
+			return;
+		}
+		c = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+	}
+	else
+		c = cfg_Read("paths","default playlist","");
+		
+	entries = CreateWaitDialog((GThreadFunc)pl_LoadList,c,NULL,pl_LoadListProgress, _("Loading Playlist"));
+	if (g_list_length(entries) != 0)
+	{
+		if ((gint) callback_action != 3) cfg_Write("paths","playlist",c);	  
+		if ((gint) callback_action == 1 )
+		{
+			gtk_tree_selection_select_all(selection);
+			toolbar_RemoveFiles(NULL,0,NULL);
+		}
+	}
+		if ((gint) callback_action != 3) gtk_widget_destroy (dialog);
+		gtk_widget_grab_focus (tv);
 
-     GtkWidget* tv;
-     GtkTreeModel* model;
-     GtkTreeSelection* selection;
-     GtkTreeIter iter;
-     GList* entries = NULL, *p =NULL;
-     GtkWidget* filesel;
-     gchar* c;
-
-     tv = MW_GET("left_treeview");
-     model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
-     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tv));
-     if ((gint) callback_action != 3) {
-	  filesel = gtk_file_selection_new (_("Select Playlist"));
-	  c = cfg_Read("paths","playlist","/");
-	  gtk_file_selection_set_filename (GTK_FILE_SELECTION(filesel),c);
-	  gtk_window_set_modal(GTK_WINDOW(filesel),TRUE);  
-	  gtk_window_set_transient_for(GTK_WINDOW(filesel),MainWindow);
-	  if (gtk_dialog_run(GTK_DIALOG(filesel))  != -5) {
-	       gtk_widget_destroy(filesel);
-	       return;
-	  }
-	  c = (gchar*)gtk_file_selection_get_filename(GTK_FILE_SELECTION(filesel));
-     }
-     else
-	  c = cfg_Read("paths","default playlist","");
-
-     entries = CreateWaitDialog((GThreadFunc)pl_LoadList,c,NULL,pl_LoadListProgress,
-	 											    _("Loading Playlist"));
-
-     if (g_list_length(entries) != 0) {
-	  if ((gint) callback_action != 3) cfg_Write("paths","playlist",c);	  
-	  if ((gint) callback_action == 1 )
-	  {
-	       gtk_tree_selection_select_all(selection);
-	       toolbar_RemoveFiles(NULL,0,NULL);
-	  }
-     }
-     if ((gint) callback_action != 3) gtk_widget_destroy(filesel);
-     gtk_widget_grab_focus (tv);
-
-     for(p = entries;p;p = g_list_next(p)) {
-	  gtk_list_store_append(GTK_LIST_STORE(model),&iter);     
-	  gtk_list_store_set(GTK_LIST_STORE(model),&iter,0,p->data,-1);
-     }
-     tv = MW_GET("left_statusbar");
-     gtk_statusbar_pop(GTK_STATUSBAR(tv),0);
-     if (g_list_length(entries) !=0)
-	  gtk_statusbar_push(GTK_STATUSBAR(tv),0,_("Loaded Playlist"));
-     else {
-	  if ((gint) callback_action != 3)
-	       gtk_statusbar_push(GTK_STATUSBAR(tv),0,_("Error Loading Playlist"));
-     }
-     g_list_free(entries);
+	for(p = entries;p;p = g_list_next(p))
+	{
+		gtk_list_store_append(GTK_LIST_STORE(model),&iter);     
+		gtk_list_store_set(GTK_LIST_STORE(model),&iter,0,p->data,-1);
+	}
+	tv = MW_GET("left_statusbar");
+	gtk_statusbar_pop(GTK_STATUSBAR(tv),0);
+	if (g_list_length(entries) !=0)
+		gtk_statusbar_push(GTK_STATUSBAR(tv),0,_("Loaded Playlist"));
+	else
+	{
+		if ((gint) callback_action != 3)
+			gtk_statusbar_push(GTK_STATUSBAR(tv),0,_("Error Loading Playlist"));
+	}
+	g_list_free(entries);
 }
 
+void menuitem_SavePlaylist(gpointer callback_data,guint  callback_action,GtkWidget *widget)
+{
 
-void menuitem_SavePlaylist(gpointer callback_data,
-		     guint  callback_action,
-		     GtkWidget *widget) {
-     GtkWidget* tv;
-     GtkTreeModel* model;
-     GtkTreeIter iter;
-     GList* entries = NULL, *p =NULL;
-     GtkWidget* filesel;
-     gchar* c;
-
-     tv = MW_GET("left_treeview");
-     model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
-     if ((gint) callback_action != 3) {
-
-	  filesel = gtk_file_selection_new (_("Save Playlist"));
-	  c = cfg_Read("paths","playlist","/");
-	  gtk_file_selection_set_filename (GTK_FILE_SELECTION(filesel),c);
-	  gtk_window_set_modal(GTK_WINDOW(filesel),TRUE);  
-	  gtk_window_set_transient_for(GTK_WINDOW(filesel),MainWindow);
-	  if (gtk_dialog_run(GTK_DIALOG(filesel))  != -5) {
-	       gtk_widget_destroy(filesel);
-	       return;
-	  }
-	  c = (gchar*)gtk_file_selection_get_filename(GTK_FILE_SELECTION(filesel));
+	GtkWidget* tv;
+	GtkTreeModel* model;
+	GtkTreeIter iter;
+	GList* entries = NULL, *p =NULL;
+	gchar* c;
+	GtkWidget *dialog;
+	GtkFileFilter *filter;	
+	
+	tv = MW_GET("left_treeview");
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(tv));
+	if ((gint) callback_action != 3)
+	{
+		dialog = gtk_file_chooser_dialog_new (_("Save playlist..."),MainWindow,GTK_FILE_CHOOSER_ACTION_SAVE,GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,NULL);
+		filter = gtk_file_filter_new ();
+		gtk_file_filter_set_name (filter, _("Playlists"));
+		gtk_file_filter_add_pattern (filter, "*.m3u");
+		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
+		c = cfg_Read("paths","playlist","/");
+		gtk_file_chooser_set_filename   (GTK_FILE_CHOOSER (dialog),c);
+		gtk_window_set_modal(GTK_WINDOW(dialog),TRUE);  
+		gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+		
+	  
+	if (result == GTK_RESPONSE_CANCEL)
+	{
+		gtk_widget_destroy (dialog);
+		return;
+	}
+		c = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
      }
      else
 	  c = cfg_Read("paths","default playlist","");
 
      if (gtk_tree_model_get_iter_first(model,&iter) == FALSE) {
 	   if ((gint) callback_action != 3) 
-		gtk_widget_destroy(filesel);
+		gtk_widget_destroy (dialog);
 	   else
 		unlink(c);
 	  return;
@@ -1149,7 +1190,7 @@ void menuitem_SavePlaylist(gpointer callback_data,
 //	  g_print("saved\n");
 
      }
-	 if ((gint) callback_action != 3)     gtk_widget_destroy(filesel);
+	 if ((gint) callback_action != 3)	gtk_widget_destroy (dialog);
      g_list_free(entries);
 
 }
@@ -1231,19 +1272,19 @@ void menuitem_FormatMem(gpointer callback_data,guint  callback_action,GtkWidget
 static GtkItemFactoryEntry menu_items[] = {
 	{ N_("/_File"),            NULL,         0,                     0, "<Branch>" },
      { N_("/File/_Add"),          NULL ,NULL,       0, "<Branch>"},
-     { N_("/File/Add/Directory"),          NULL ,G_CALLBACK(popup_AddDirectory),       0, "<Item>"},
-     { N_("/File/Add/File"),          NULL ,G_CALLBACK(popup_AddFile),       0, "<Item>"},
+     { N_("/File/Add/Directory..."),          NULL ,G_CALLBACK(popup_AddDirectory),       0, "<Item>"},
+     { N_("/File/Add/File..."),          NULL ,G_CALLBACK(popup_AddFile),       0, "<Item>"},
 	 { N_("/File/sep1"),        NULL,NULL,       0, "<Separator>"},
-     { N_("/File/_Send"),        "Return",toolbar_SendFiles,       0, "<StockItem>", GTK_STOCK_GO_FORWARD },
+     { N_("/File/_Send..."),        "Return",toolbar_SendFiles,       0, "<StockItem>", GTK_STOCK_GO_FORWARD },
    	 { N_("/File/_Remove"),   "Delete",toolbar_RemoveFiles,       0, "<StockItem>", GTK_STOCK_REMOVE },     
      { N_("/File/_Properties"),NULL,toolbar_FileProperties, 0, "<StockItem>", GTK_STOCK_PROPERTIES },
      { N_("/File/sep1"),        NULL,NULL,       0, "<Separator>"},
-	 { N_("/File/Send non mp3 file"), NULL,menuitem_SendNonMp3,       0, "<StockItem>", GTK_STOCK_JUSTIFY_FILL },
+	 { N_("/File/Send non mp3 file..."), NULL,menuitem_SendNonMp3,       0, "<StockItem>", GTK_STOCK_FILE },
 	 { N_("/File/sep1"),        NULL,NULL,       0, "<Separator>"},
      { N_("/File/_Quit"),       NULL ,mw_Destroy,       0, "<StockItem>", GTK_STOCK_QUIT },
      {N_("/_Mpman"),NULL,0,0,"<Branch>"},
-     {N_("/Mpman/_Rfresh"), "<control>r",toolbar_Refresh,0,"<StockItem>",GTK_STOCK_REFRESH},
-     { N_("/Mpman/_Get"), "<shift>Return",toolbar_GetFiles,       0, "<StockItem>", GTK_STOCK_GO_BACK },
+     {N_("/Mpman/_Refresh"), "<control>r",toolbar_Refresh,0,"<StockItem>",GTK_STOCK_REFRESH},
+     { N_("/Mpman/_Get..."), "<shift>Return",toolbar_GetFiles,       0, "<StockItem>", GTK_STOCK_GO_BACK },
      { N_("/Mpman/_Delete"), "<shift>Delete",toolbar_MpDelete,       0, "<StockItem>", GTK_STOCK_DELETE },
 	 { N_("/Mpman/sep1"), NULL,NULL,       0, "<Separator>"},
 	 { N_("/Mpman/Format Internal Memory"), NULL,menuitem_FormatMem, FLASH, "<Item>" },
@@ -1254,13 +1295,13 @@ static GtkItemFactoryEntry menu_items[] = {
      { N_("/Edit/sep1"),        NULL,NULL,       0, "<Separator>"},
      {N_("/Edit/_Options"), NULL,menuitem_Options,0,"<StockItem>",GTK_STOCK_PREFERENCES},
      { N_("/_Playlist"),            NULL,         0,                     0, "<Branch>" },
-     { N_("/Playlist/_Load"),        "<control>L",menuitem_LoadPlaylist,       1, "<StockItem>", GTK_STOCK_OPEN },
-     { N_("/Playlist/_Add"), NULL,menuitem_LoadPlaylist,       0, "<StockItem>", GTK_STOCK_ADD },
+     { N_("/Playlist/_Load..."),        "<control>L",menuitem_LoadPlaylist,       1, "<StockItem>", GTK_STOCK_OPEN },
+     { N_("/Playlist/_Add..."), NULL,menuitem_LoadPlaylist,       0, "<StockItem>", GTK_STOCK_ADD },
      { N_("/Playlist/sep1"),        NULL,NULL,       0, "<Separator>"},
-     { N_("/Playlist/Sa_ve as"),        "<control>S",menuitem_SavePlaylist,       0, "<StockItem>", GTK_STOCK_SAVE_AS },
+     { N_("/Playlist/Sa_ve as..."),        "<control>S",menuitem_SavePlaylist,       0, "<StockItem>", GTK_STOCK_SAVE_AS },
      { N_("/Playlist/Save as Default"),   NULL,menuitem_SavePlaylist,       3, "<StockItem>", GTK_STOCK_SAVE_AS },
      { N_("/Help"),            NULL, 0,                     0, "<Branch>" },
-     { N_("/Help/About"), NULL,menuitem_About,       0, "<Item>" },
+     { N_("/Help/About"), NULL,menuitem_About,       0, "<StockItem>",GTK_STOCK_ABOUT },
 
 };
 
