@@ -430,7 +430,7 @@ gint expose_cb (GtkWidget	  *widget,
      guchar *pixels;
      int rowstride;
 
-     (gpointer) frame = data;
+     frame = (GdkPixbuf*)data;
 
      rowstride = gdk_pixbuf_get_rowstride (frame);
      pixels = gdk_pixbuf_get_pixels (frame) + rowstride * event->area.y + event->area.x * 4;
@@ -454,8 +454,7 @@ gint timeout (gpointer data) {
      float para;
      static float  multiplier = 0.0;
      static unsigned char lcolor = 1;
-
-     (gpointer) frame = data;
+     frame = (GdkPixbuf*)data;
 
      rowstride = gdk_pixbuf_get_rowstride (frame);
      pixels = gdk_pixbuf_get_pixels(frame);
@@ -495,7 +494,7 @@ cleanup_callback (GtkObject *object,
      g_source_remove (timeout_id);
   timeout_id = 0;
   
-  (gpointer) frame = data;
+  frame = (GdkPixbuf*) data;
   g_object_unref(frame);
   g_object_unref(buffer);
   gtk_widget_destroy(GTK_WIDGET(object));
@@ -549,115 +548,40 @@ void unset_can_focus(GtkWidget* widget,gpointer data) {
 	 g_object_set(widget,"can-focus",FALSE,NULL);
 }
 
-void create_about_window() {
-     GtkWidget* window1;
-     GtkWidget *image1;
-     GtkWidget *label1;
-     GtkWidget* hbox;
-     GtkWidget* ebox;
-     GtkWidget* scroller;
-     GtkTextBuffer* textbuffer;
-     GtkWidget* textview;
-     GtkTextMark* mark;
-     GtkTextIter end;
-     GString* text = g_string_new("");
-
-    window1 = gtk_dialog_new_with_buttons("Mplinuxman",MainWindow,
-					  GTK_DIALOG_MODAL & 
-					     GTK_DIALOG_DESTROY_WITH_PARENT,
-					     GTK_STOCK_CLOSE,GTK_RESPONSE_OK,NULL);
-
-    hbox = gtk_hbox_new(FALSE,0);
-    gtk_widget_show(hbox);
-   	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window1)->vbox),hbox,FALSE,FALSE,5);
-//    gtk_container_add (GTK_CONTAINER(GTK_DIALOG(window1)->vbox), hbox);
-	//gtk_dialog_set_has_separator (GTK_DIALOG(window1),FALSE);
-    gtk_container_set_border_width(GTK_CONTAINER(window1),5);
-    gtk_window_set_default_size(GTK_WINDOW(window1),400,300);
-    image1 = gtk_image_new_from_pixbuf(MW_GET("mp_icon"));
-    gtk_misc_set_alignment(GTK_MISC(image1),0,0);
-    ebox = gtk_event_box_new();
-    gtk_container_add(GTK_CONTAINER(ebox),image1);
-    g_signal_connect(ebox,"button-press-event",G_CALLBACK(image_button_event),window1);
-    gtk_widget_show (image1);
-    gtk_widget_show (ebox);
-    gtk_box_pack_end(GTK_BOX(hbox),ebox,FALSE,FALSE,0);
-    g_string_printf(text, "<span weight=\"bold\" size=\"larger\">Mplinuxman version %s</span>\n"
-										,MP_VERSION);
-    label1 = gtk_label_new("");
-    gtk_label_set_markup(GTK_LABEL(label1), text->str);
-    
-    gtk_widget_show (label1);
-    gtk_box_pack_start(GTK_BOX(hbox),label1,FALSE,FALSE,0);
-    	
-	scroller = gtk_scrolled_window_new(NULL,NULL);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroller),
-												  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scroller),
-															GTK_SHADOW_IN);												  
-	textbuffer = gtk_text_buffer_new(NULL);
-	gtk_text_buffer_create_tag(GTK_TEXT_BUFFER(textbuffer),"bold", "weight", 
-											PANGO_WEIGHT_BOLD, NULL);
-	gtk_text_buffer_create_tag(GTK_TEXT_BUFFER(textbuffer),"blue", "foreground", 
-											"blue", NULL);
-
-	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER(textbuffer), &end, -1);
-												
-	gtk_text_buffer_insert(GTK_TEXT_BUFFER(textbuffer), &end , "URL:   ",-1);
-	gtk_text_buffer_insert_with_tags_by_name (GTK_TEXT_BUFFER(textbuffer), &end,
-	 "http://mplinuxman.sourceforge.net\n\n",-1, "blue" ,NULL);
-	 gtk_text_buffer_insert(GTK_TEXT_BUFFER(textbuffer), &end , "Help:   ",-1);
-	 gtk_text_buffer_insert_with_tags_by_name (GTK_TEXT_BUFFER(textbuffer), &end,
-	 "http://mplinuxman.sourceforge.net/index.php?page=2\n\n",-1, "blue" ,NULL);
-	gtk_text_buffer_insert_with_tags_by_name (GTK_TEXT_BUFFER(textbuffer), &end,
-	 "Languages\n",-1, "bold" ,NULL);
-	gtk_text_buffer_insert(GTK_TEXT_BUFFER(textbuffer), &end ,
-	"If you would like to contribute a translation to your "
- 	"native language, please email the translation file "
-	"to me.\n\n",-1);
-	gtk_text_buffer_insert_with_tags_by_name (GTK_TEXT_BUFFER(textbuffer), &end,
-	 "Credits\n",-1, "bold" ,NULL);
-	gtk_text_buffer_insert(GTK_TEXT_BUFFER(textbuffer), &end ,
-	"Written by Tim O'Brien  ",-1);
-	gtk_text_buffer_insert_with_tags_by_name (GTK_TEXT_BUFFER(textbuffer), &end,
-	 "mild7@users.sourceforge.net\n\n",-1, "blue" ,NULL);
-	gtk_text_buffer_insert_with_tags_by_name (GTK_TEXT_BUFFER(textbuffer), &end,
-	 "Testing and patches\n",-1, "bold" ,NULL);
-	gtk_text_buffer_insert(GTK_TEXT_BUFFER(textbuffer), &end ,
-	"Kazutaka Manabe\nChristian von Eichel-Streiber\n"
-	"Tholom Kiely\nKris Meeusen\n\n",-1);
-	gtk_text_buffer_insert_with_tags_by_name (GTK_TEXT_BUFFER(textbuffer), &end,
-	 "Translations\n",-1, "bold" ,NULL);
-	gtk_text_buffer_insert(GTK_TEXT_BUFFER(textbuffer), &end ,
-										"French		Thomas Jost\n"
-										"Spanish		Marcos Mainar\n"
-										"Dutch			Bosko Andjelkovic\n"
-										"German		Thomas Ritter\n"
-										"Japanese		Shimada Hirofumi\n",-1);
-										
-	textview = gtk_text_view_new_with_buffer(GTK_TEXT_BUFFER(textbuffer));
-	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(textview), GTK_WRAP_WORD);
-//	gtk_text_view_set_right_margin(GTK_TEXT_VIEW(textview), 80);
-	gtk_text_view_set_editable(GTK_TEXT_VIEW(textview), FALSE);
-
-	gtk_container_add(GTK_CONTAINER(scroller), textview);
-	//gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window1)->vbox),gtk_hseparator_new(),FALSE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window1)->vbox),scroller,TRUE,TRUE,0);
-    gtk_dialog_set_has_separator (GTK_DIALOG(window1),FALSE);
-    gtk_container_foreach(GTK_CONTAINER(GTK_DIALOG(window1)->action_area),
-			  ButtonRelief,(gpointer)GTK_RELIEF_NONE);
-	gtk_container_foreach(GTK_CONTAINER(GTK_DIALOG(window1)->action_area),
-			  unset_can_focus,(gpointer)NULL);
+void create_about_window()
+{
+	const char **tem;
+	const char *authors[] = {
+		"",
+		"Tim O'Brien <mild7@users.sourceforge.net>",
+		"Boško Andjelković <erlenmeyer@users.sourceforge.net>",
+		"",
+		NULL,
+		"Tholom Kiely",
+		"Kazutaka Manabe",
+		"Kris Meeusen",
+		"Christian von Eichel-Streiber",
+		"",
+		NULL
+	};
 	
-	gtk_widget_show_all(window1);
-	
-	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER(textbuffer), &end, 0);
-	gtk_text_buffer_place_cursor(GTK_TEXT_BUFFER(textbuffer), &end);
-	mark = gtk_text_buffer_create_mark(GTK_TEXT_BUFFER(textbuffer),"start_mark",
-														 &end, FALSE);
-	gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(textview), mark, 0, TRUE, 0, 0);	
-	
-    gtk_dialog_run(GTK_DIALOG(window1));
-    gtk_widget_destroy(window1);
-    g_string_free(text,TRUE);
+	authors[0] = _("Lead developers:");
+	for (tem = authors; *tem != NULL; tem++)
+		;
+	*tem = _("Testing and patches:");
+
+	static const gchar copyright[] = \
+		"Copyright \xc2\xa9 2002-2006 Tim O'Brien\n"
+		"Copyright \xc2\xa9 2006 Boško Andjelković\n";
+		
+	gtk_show_about_dialog (GTK_WINDOW (MainWindow),
+			       "authors", (const char **) authors,
+			       "comments", _("Mplinuxman is a file manager program for the MPMan F60,F55,F50, and d-link dmp-220 USB portable MP3 players."),
+			       "copyright", copyright,
+			       "logo", MW_GET("mp_icon"),
+			       "translator-credits", "Boško Andjelković\nShimada Hirofumi\nThomas Jost\nMarcos Mainar\nThomas Ritter\n",
+			       "version", MP_VERSION,
+			       "website", "http://mplinuxman.sourceforge.net",
+			       "name", "Mplinuxman",
+			       NULL); 
 }
